@@ -43,10 +43,13 @@ class Person(BASE):
     earnings = Column(Float)
     first_name = Column(String)
     last_name = Column(String)
+    birthday = Column(DateTime)
     portrait = Column(LargeBinary)
     twitch = Column(String)
     mixer = Column(String)
     youtube = Column(String)
+    discord = Column(String)
+    douyu = Column(String)
 
 
 class Event(BASE):
@@ -539,9 +542,23 @@ class Timeseries(BASE):
     value_current_units = Column(Integer)
     value_current_buildings = Column(Integer)
     value_objects_destroyed = Column(Integer)
+    value_units_killed = Column(Integer)
+    value_buildings_razed = Column(Integer)
+    hit_points_razed = Column(Integer)
+    hit_points_killed = Column(Integer)
+    villager_high = Column(Integer)
+    military_high = Column(Integer)
+    buildings_lost = Column(Integer)
     kills = Column(Integer)
     razes = Column(Integer)
     deaths = Column(Integer)
+    trained = Column(Integer)
+    converted = Column(Integer)
+    total_score = Column(Integer)
+    military_score = Column(Integer)
+    economy_score = Column(Integer)
+    society_score = Column(Integer)
+    technology_score = Column(Integer)
     __table_args__ = (
         ForeignKeyConstraint(['match_id', 'player_number'], ['players.match_id', 'players.number'], ondelete='cascade'),
     )
